@@ -1,6 +1,6 @@
 package MooX::Role::Parameterized;
 {
-    $MooX::Role::Parameterized::VERSION = '0.05';
+    $MooX::Role::Parameterized::VERSION = '0.06';
 }
 use strict;
 use warnings;
@@ -18,7 +18,9 @@ sub apply {
 
     return if !exists $code_for{$role};
 
-    $code_for{$role}->($args);
+    $args = [$args] if ref($args) ne ref( [] );
+
+    $code_for{$role}->($_) foreach ( @{$args} );
 
     my $target = $extra{target} // caller;
     require Moo::Role;
@@ -73,10 +75,14 @@ MooX::Role::Parameterized - roles with composition parameters
     use Moo;
     use My::Role;
 
-    My::Role->apply({    # original way of add this role
-        attr => 'baz',   # add attribute read-write called 'baz' 
-        method => 'run'  # add method called 'run' and return 1024 
-    });
+    My::Role->apply([{    # original way of add this role
+        attr => 'baz',    # add attribute read-write called 'baz' 
+        method => 'run'   # add method called 'run' and return 1024 
+    }
+     ,                    # and if the apply receives one arrayref
+    {   attr => 'bam',    # will call the role block multiple times.
+        method => 'jump'  # PLEASE CALL apply once
+    }]);      
 
 =head1 DESCRIPTION
 
@@ -92,6 +98,8 @@ When called, will apply the L</role> on the current package. The behavior depend
 
 This will install the role in the target package. Does not need call C<with>.
 
+Important, if you want to apply the role multiple times, like to create multiple attributes, please pass an B<arrayref>.
+
 =head2 role
 
 This function accepts one code block. Will execute this code then we apply the Role in the 
